:root {
  --md-primary-fg-color:             #001425;
  --md-primary-fg-color--light:      #308AAD;
  --md-primary-fg-color--dark:       #001425;
  --md-accent-fg-color:              #308AAD;
  --md-accent-fg-color--transparent: #308AAD;
}

p a {
    text-decoration: underline;
}

.md-header__button.md-logo img,
.md-header__button.md-logo svg {
  height: 2.4rem;
  width: 2.4rem;
}
